@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2010 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,15 +21,14 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: conf.h,v 1.8 2007-04-14 18:04:17 thib Exp $ */
 
 #ifndef __CONF_H__
 #define __CONF_H__
 
 /* functions prototypes */
 extern void reload_all(const char *dir_name);
-extern void synchronize_dir(const char *dir_name);
+extern void synchronize_dir(const char *dir_name, int is_system_startup);
 extern void delete_file(const char *user_name);
 extern void save_file(struct cf_t *file_name);
 
-#endif /* __CONF_H__ */
+#endif                          /* __CONF_H__ */
