@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2010 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: convert-fcrontab.h,v 1.5 2007-04-14 18:04:21 thib Exp $ */
 
 #ifndef __CONVERT_FCRONTAB_H__
 #define __CONVERT_FCRONTAB_H__
@@ -31,7 +30,10 @@
 
 #include "global.h"
 
+/* needed for parsing a conf file */
+#include "fcronconf.h"
+
 extern uid_t rootuid;
 extern gid_t rootgid;
 
-#endif /* __CONVERT_FCRONTAB_H__ */
+#endif                          /* __CONVERT_FCRONTAB_H__ */
