@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2010 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,15 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: fcron.h,v 1.35 2007-04-14 18:04:14 thib Exp $ */
 
 #ifndef __FCRON_H__
 #define __FCRON_H__
 
 #include "global.h"
+#include "mem.h"
+#include "exe_list.h"
+#include "lavg_list.h"
+#include "fcronconf.h"
 
 #ifdef HAVE_CRYPT_H
 #include <crypt.h>
@@ -60,9 +63,8 @@
 
 /* global variables */
 extern time_t now;
-extern char debug_opt;
 extern char foreground;
-extern char dosyslog;
+extern char default_mail_charset[TERM_LEN];
 extern time_t first_sleep;
 extern char *cdir;
 extern pid_t daemon_pid;
@@ -80,15 +82,11 @@ extern short int serial_array_size;
 extern short int serial_array_index;
 extern short int serial_num;
 extern short int serial_running;
-extern short int serial_max_running; 
+extern short int serial_max_running;
 extern short int serial_queue_max;
 extern short int lavg_queue_max;
-extern struct exe_t *exe_array;
-extern short int exe_array_size;
-extern short int exe_num;
-extern struct lavg_t *lavg_array;
-extern short int lavg_array_size;
-extern short int lavg_num;
+extern exe_list_t *exe_list;
+extern lavg_list_t *lavg_list;
 extern short int lavg_serial_running;
 /* end of global variables */
 
@@ -98,5 +96,4 @@ extern short int lavg_serial_running;
 /* fcron.c */
 extern void xexit(int exit_value);
 
-#endif /* __FCRON_H */
-
+#endif                          /* __FCRON_H */
