@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2010 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,25 +21,25 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: fcrondyn.h,v 1.7 2007-04-14 18:04:11 thib Exp $ */
 
 #ifndef __FCRONDYN_H__
 #define __FCRONDYN_H__
 
 #include "global.h"
 #include "dyncom.h"
+#include "fcronconf.h"
 
 /* global variables */
-extern char debug_opt;
-extern char dosyslog;
 extern pid_t daemon_pid;
 extern uid_t rootuid;
 extern gid_t rootgid;
 
 /* types def */
+#define MAX_NUM_ALIAS 2
 #define MAX_NUM_OPT 4
 typedef struct cmd_list_ent {
     char *cmd_name;
+    char *cmd_alias[MAX_NUM_ALIAS];
     char *cmd_desc;
     int cmd_numopt;
     long int cmd_code;
@@ -47,4 +47,4 @@ typedef struct cmd_list_ent {
     int cmd_default[MAX_NUM_OPT];
 } cmd_list_ent;
 
-#endif /* __FCRONDYN_H__ */
+#endif                          /* __FCRONDYN_H__ */
