@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2010 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,17 +21,16 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: fcrontab.h,v 1.21 2007-04-14 18:04:13 thib Exp $ */
 
 #ifndef __FCRONTAB_H__
 #define __FCRONTAB_H__
 
 #include "global.h"
+#include "mem.h"
+#include "fcronconf.h"
 
 /* global variables */
-extern char debug_opt;
 extern pid_t daemon_pid;
-extern char dosyslog;
 extern struct cf_t *file_base;
 extern char *user;
 extern char *runas;
@@ -42,4 +41,4 @@ extern gid_t fcrontab_gid;
 extern uid_t rootuid;
 extern gid_t rootgid;
 
-#endif /* __FCRONTAB_H__ */
+#endif                          /* __FCRONTAB_H__ */
