@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2010 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: global.h,v 1.51 2007-06-24 22:01:49 thib Exp $ */
 
 
 /* 
@@ -62,6 +61,9 @@
 #include <limits.h>
 #endif
 
+#include <locale.h>
+#include <nl_types.h>
+#include <langinfo.h>
 #include <pwd.h>
 #include <signal.h>
 
@@ -112,15 +114,34 @@
 #include <sys/fcntl.h>
 #endif
 
+#ifdef HAVE_CRED_H
+#include <cred.h>
+#endif
+#ifdef HAVE_UCRED_H
+#include <ucred.h>
+#endif
+#ifdef HAVE_SYS_CRED_H
+#include <sys/cred.h>
+#endif
+#ifdef HAVE_SYS_UCRED_H
+#include <sys/ucred.h>
+#endif
+
+#ifdef WITH_AUDIT
+#include <libaudit.h>
+#endif
+
 #ifdef HAVE_LIBPAM
 #include "pam.h"
 #endif
 
-#include "bitstring.h"     /* bit arrays */
-#include "option.h"        /* manage fcrontab's options */
+#include "bitstring.h"          /* bit arrays */
+#include "option.h"             /* manage fcrontab's options */
+#include "env_list.h"           /* manage fcrontab's environment variable lists */
+#include "cl.h"                 /* Cron Line cl_t type and associated functions */
 
 /* you should not change this (nor need to do it) */
-#define ERR     -1           
+#define ERR     -1
 #define OK       0
 
 /* options for local functions */
@@ -135,22 +156,6 @@
 #define setegid(arg) setresgid(-1,(arg),-1)
 #endif
 
-#define Alloc(PTR, TYPE) \
-        if( (PTR = calloc(1, sizeof(TYPE))) == NULL ) \
-            die_e("Could not calloc.");
-
-#define Set(VAR, VALUE) \
-        { \
-          free(VAR); \
-          VAR = strdup2(VALUE); \
-        }
-
-#define Flush(VAR) \
-        { \
-          free(VAR); \
-          VAR = NULL; \
-	}
-
 #define Skip_blanks(PTR) \
         while((*(PTR) == ' ') || (*(PTR) == '\t')) \
 	    (PTR)++;
@@ -165,18 +170,13 @@
 
 #define debug if(debug_opt) Debug
 
-typedef struct env_t {
-    char         *e_val;        /* env value                            */
-    struct env_t *e_next;
-} env_t ;
-
 typedef struct cf_t {
-    struct cf_t  *cf_next;
-    struct cl_t  *cf_line_base;
-    char	 *cf_user;	/* user-name			             */
-    struct env_t *cf_env_base;  /* list of all env variables to set          */
-    int		  cf_running;	/* number of jobs running                    */
-    signed char	  cf_tzdiff;    /* time diff between system and local hour   */
+    struct cf_t *cf_next;
+    struct cl_t *cf_line_base;
+    char *cf_user;              /* user-name                                 */
+    env_list_t *cf_env_list;    /* list of all parsed env var                */
+    int cf_running;             /* number of jobs running                    */
+    signed char cf_tzdiff;      /* time diff between system and local hour   */
 #ifdef WITH_SELINUX
     security_context_t cf_user_context;
     security_context_t cf_file_context;
@@ -184,54 +184,11 @@ typedef struct cf_t {
 } cf_t;
 
 
-#define OPTION_SIZE 4
-#define LAVG_SIZE 3
-/* warning : do not change the order of the members of this structure
- *   because some tests made are dependent to that order */
-/* warning : if you change a field type, you may have to also make some changes
- *   in the save/load binary fcrontab functions */
-typedef struct cl_t {
-    struct cl_t   *cl_next;
-    struct cf_t   *cl_file;       /* the file in which the line is           */
-    char	  *cl_shell;      /* shell command			     */
-    char          *cl_runas;      /* determine permissions of the job        */
-    char          *cl_mailto;     /* mail output to cl_mailto                */
-    char          *cl_tz;         /* time zone of the line                   */
-    long int       cl_id;         /* line's unique id number                 */
-    time_t         cl_until;      /* timeout of the wait for a lavg value    */
-    time_t         cl_first;      /* initial delay preserved for volatile entries */
-    time_t         cl_nextexe;    /* time and date of the next execution     */
-    long int       cl_timefreq;   /* Run every n seconds                     */
-    unsigned short cl_remain;     /* remaining until next execution          */
-    unsigned short cl_runfreq;    /* Run once every n matches(=1 for %-lines)*/
-    unsigned char  cl_option[OPTION_SIZE]; /* line's option (see option.h)   */
-    unsigned char  cl_lavg[LAVG_SIZE];/*load averages needed (1,5,15 mins)   */
-    unsigned char  cl_numexe;     /* entries in queues & running processes   */
-    char           cl_nice;       /* nice value to control priority          */
-    /* see bitstring(3) man page for more details */
-    bitstr_t	   bit_decl(cl_mins, 60); /* 0-59		             */
-    bitstr_t	   bit_decl(cl_hrs, 24);  /* 0-23			     */
-    bitstr_t	   bit_decl(cl_days, 32); /* 1-31			     */
-    bitstr_t	   bit_decl(cl_mons, 12); /* 0-11                	     */
-    bitstr_t	   bit_decl(cl_dow, 8);	  /* 0-7, 0 and 7 are both Sunday    */
-} cl_t;
-
 typedef struct job_t {
-    struct cl_t  *j_line;
-    struct job_t   *j_next;
+    struct cl_t *j_line;
+    struct job_t *j_next;
 } job_t;
 
-typedef struct lavg_t {
-    struct cl_t *l_line;  
-    time_t       l_until;   /* the timeout of the wait for load averages */
-} lavg_t;
-
-typedef struct exe_t {
-    struct cl_t *e_line;
-    pid_t        e_ctrl_pid; /* pid of the fcron process controling the job */
-    pid_t        e_job_pid;  /* pid of the job itself */
-} exe_t;
-
 
 #if SIZEOF_TIME_T == SIZEOF_SHORT_INT
 #define ATTR_SIZE_TIMET "h"
@@ -277,5 +234,4 @@ typedef struct exe_t {
 #include "subs.h"
 
 
-#endif /* __GLOBAL_H__ */
-
+#endif                          /* __GLOBAL_H__ */
