@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2010 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,15 +21,18 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: job.h,v 1.10 2008-05-11 15:05:35 thib Exp $ */
 
 #ifndef __JOB_H__
 #define __JOB_H__
 
 /* functions prototypes */
-extern int change_user(struct cl_t *cl);
+extern void change_user_setup_env(struct cl_t *cl, char ***sendmailenv,
+                                  char ***jobenv, char **curshell,
+                                  char **curhome, char **content_type,
+                                  char **encoding);
 extern int run_job(struct exe_t *exeent);
-extern FILE *create_mail(struct cl_t *line, char *subject);
-extern void launch_mailer(struct cl_t *line, FILE *mailf);
+extern FILE *create_mail(struct cl_t *line, char *subject, char *content_type,
+                         char *encoding, char **env);
+extern void launch_mailer(struct cl_t *line, FILE * mailf, char **env);
 
-#endif /* __JOB_H__ */
+#endif                          /* __JOB_H__ */
