@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2010 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2012 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,40 +21,27 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: subs.h,v 1.11 2007-04-14 18:04:23 thib Exp $ */
 
 #ifndef __SUBS_H__
 #define __SUBS_H__
 
 
-/* global variables */
-
-/* fcron.conf parameters */
-extern char *fcronconf;
-extern char *fcronallow;
-extern char *fcrondeny;
-extern char *fcrontabs;
-extern char *pidfile;
-extern char *fifofile;
-extern char *editor;
-extern char *shell;
-extern char *sendmail;
-/* end of global variables */
-
 /* functions prototypes */
 extern uid_t get_user_uid_safe(char *username);
 extern gid_t get_group_gid_safe(char *groupname);
 extern void seteuid_safe(uid_t euid);
 extern void setegid_safe(uid_t egid);
-extern int remove_as_user(const char *pathname, uid_t removeuid, gid_t removegid);
-extern int open_as_user(const char *pathname, uid_t openuid, gid_t opengid, int flags, ...);
-extern int rename_as_user(const char *oldpath, const char *newpath, uid_t renameuid, gid_t renamegid);
+extern int remove_as_user(const char *pathname, uid_t removeuid,
+                          gid_t removegid);
+extern int open_as_user(const char *pathname, uid_t openuid, gid_t opengid,
+                        int flags, ...);
+extern int rename_as_user(const char *oldpath, const char *newpath,
+                          uid_t renameuid, gid_t renamegid);
 
 extern int remove_blanks(char *str);
-extern char *strdup2(const char *);
+extern int strcmp_until(const char *left, const char *right, char until);
 extern int get_word(char **str);
-extern int temp_file(char **name);
-extern void read_conf(void);
-extern void free_conf(void);
+extern void my_unsetenv(const char *name);
+extern void my_setenv_overwrite(const char *name, const char *value);
 
-#endif /* __SUBS_H__ */
+#endif                          /* __SUBS_H__ */
